==> dtkdeclarative_5.7.21.tar.xz: BUILD/src/translations/dtkdeclarative_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AboutAction</name>
    <message>
        <location filename="../qml/AboutAction.qml" line="9"/>
        <source>About</source>
        <translation>Mbi</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../qml/AboutDialog.qml" line="83"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="97"/>
        <source>Homepage</source>
        <translation>Faqe hyrëse</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="112"/>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
</context>
<context>
    <name>HelpAction</name>
    <message>
        <location filename="../qml/HelpAction.qml" line="10"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
</context>
<context>
    <name>QuitAction</name>
    <message>
        <location filename="../qml/QuitAction.qml" line="9"/>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>SearchEdit</name>
    <message>
        <location filename="../qml/SearchEdit.qml" line="41"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../qml/settings/SettingsDialog.qml" line="79"/>
        <source>Restore Defaults</source>
        <translation>Rikthe Parazgjedhjet</translation>
    </message>
</context>
<context>
    <name>TextField</name>
    <message>
        <location filename="../qml/TextField.qml" line="71"/>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="78"/>
        <source>Cut</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="85"/>
        <source>Paste</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="91"/>
        <source>Select All</source>
        <translation>Përzgjidhi Krejt</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="98"/>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="105"/>
        <source>Redo</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThemeMenu</name>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="11"/>
        <source>Theme</source>
        <translation>Temë</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="23"/>
        <source>Light Theme</source>
        <translation>Temë e Çelët</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="29"/>
        <source>Dark Theme</source>
        <translation>Temë e Errët</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="35"/>
        <source>System Theme</source>
        <translation>Temë Sistemi</translation>
    </message>
</context>
</TS>

==> dtkdeclarative_5.7.26.tar.xz: BUILD/src/translations/dtkdeclarative_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>AboutAction</name>
    <message>
        <location filename="../qml/AboutAction.qml" line="9"/>
        <source>About</source>
        <translation>Mbi</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../qml/AboutDialog.qml" line="83"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="97"/>
        <source>Homepage</source>
        <translation>Faqe hyrëse</translation>
    </message>
    <message>
        <location filename="../qml/AboutDialog.qml" line="112"/>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
</context>
<context>
    <name>HelpAction</name>
    <message>
        <location filename="../qml/HelpAction.qml" line="10"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
</context>
<context>
    <name>QuitAction</name>
    <message>
        <location filename="../qml/QuitAction.qml" line="9"/>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>SearchEdit</name>
    <message>
        <location filename="../qml/SearchEdit.qml" line="41"/>
        <source>Search</source>
        <translation>Kërko</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../qml/settings/SettingsDialog.qml" line="79"/>
        <source>Restore Defaults</source>
        <translation>Rikthe Parazgjedhjet</translation>
    </message>
</context>
<context>
    <name>TextField</name>
    <message>
        <location filename="../qml/TextField.qml" line="71"/>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="78"/>
        <source>Cut</source>
        <translation>Prije</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="85"/>
        <source>Paste</source>
        <translation>Ngjite</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="91"/>
        <source>Select All</source>
        <translation>Përzgjidhi Krejt</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="98"/>
        <source>Undo</source>
        <translation>Zhbëje</translation>
    </message>
    <message>
        <location filename="../qml/TextField.qml" line="105"/>
        <source>Redo</source>
        <translation>Ribëje</translation>
    </message>
</context>
<context>
    <name>ThemeMenu</name>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="11"/>
        <source>Theme</source>
        <translation>Temë</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="23"/>
        <source>Light Theme</source>
        <translation>Temë e Çelët</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="29"/>
        <source>Dark Theme</source>
        <translation>Temë e Errët</translation>
    </message>
    <message>
        <location filename="../qml/ThemeMenu.qml" line="35"/>
        <source>System Theme</source>
        <translation>Temë Sistemi</translation>
    </message>
</context>
</TS>
